TinyXml: TiXmlBase Class Reference

# TiXmlBase Class Reference

TiXmlBase is a base class for every class in TinyXml. More...

`#include <tinyxml.h>`

Inheritance diagram for TiXmlBase:

List of all members.

## Public Member Functions
virtual void | Print (FILE *cfile, int depth) const =0
| All TinyXml classes can print themselves to a filestream or the string class (TiXmlString in non-STL mode, std::string in STL mode.
int | Row () const
| Return the position, in the original source file, of this node or attribute.
int | Column () const
| See Row().
void | SetUserData (void *user)
| Set a pointer to arbitrary user data.
void * | GetUserData ()
| Get a pointer to arbitrary user data.
const void * | GetUserData () const
| Get a pointer to arbitrary user data.
## Static Public Member Functions
static void | SetCondenseWhiteSpace (bool condense)
| The world does not agree on whether white space should be kept or not.
static bool | IsWhiteSpaceCondensed ()
| Return the current white space setting.
static void | EncodeString (const TIXML_STRING &str, TIXML_STRING *out)
| Expands entities in a string.
## Protected Attributes
void * | userData
| Field containing a generic user pointer.
## Friends
class | TiXmlNode
class | TiXmlElement
class | TiXmlDocument

## Detailed Description

TiXmlBase is a base class for every class in TinyXml.

It does little except to establish that TinyXml classes can be printed and provide some utility functions.

In XML, the document and elements can contain other elements and other types of nodes.

    	A Document can contain:	Element	(container or leaf)
    							Comment (leaf)
    							Unknown (leaf)
    							Declaration( leaf )

    	An Element can contain:	Element (container or leaf)
    							Text	(leaf)
    							Attributes (not on tree)
    							Comment (leaf)
    							Unknown (leaf)

    	A Decleration contains: Attributes (not on tree)

## Member Function Documentation

static void TiXmlBase::EncodeString | ( | const TIXML_STRING & | str,
|  | TIXML_STRING * | out |
| ) |  |  | `[static]`

Expands entities in a string.

Note this should not contian the tag's '<', '>', etc, or they will be transformed into entities!

virtual void TiXmlBase::Print | ( | FILE * | cfile,
|  | int | depth |
| ) |  |  | const`[pure virtual]`

All TinyXml classes can print themselves to a filestream or the string class (TiXmlString in non-STL mode, std::string in STL mode.

) Either or both cfile and str can be null.

This is a formatted print, and will insert tabs and newlines.

(For an unformatted stream, use the << operator.)

Implemented in TiXmlAttribute, TiXmlElement, TiXmlComment, TiXmlText, TiXmlDeclaration, TiXmlUnknown, and TiXmlDocument.

int TiXmlBase::Row | ( |  | ) | const`[inline]`

Return the position, in the original source file, of this node or attribute.

The row and column are 1-based. (That is the first row and first column is 1,1). If the returns values are 0 or less, then the parser does not have a row and column value.

Generally, the row and column value will be set when the TiXmlDocument::Load(), TiXmlDocument::LoadFile(), or any TiXmlNode::Parse() is called. It will NOT be set when the DOM was created from operator>>.

The values reflect the initial load. Once the DOM is modified programmatically (by adding or changing nodes and attributes) the new values will NOT update to reflect changes in the document.

There is a minor performance cost to computing the row and column. Computation can be disabled if TiXmlDocument::SetTabSize() is called with 0 as the value.

See also:
  TiXmlDocument::SetTabSize()

static void TiXmlBase::SetCondenseWhiteSpace | ( | bool | condense | ) | `[inline, static]`

The world does not agree on whether white space should be kept or not.

In order to make everyone happy, these global, static functions are provided to set whether or not TinyXml will condense all white space into a single space or not. The default is to condense. Note changing this value is not thread safe.

The documentation for this class was generated from the following file:

- tinyxml.h